@@ -559,66 +559,39 @@ def test_make_rlist_command_with_match_archives_calls_borg_with_match_archives_f
     assert command == ('borg', 'list', '--match-archives', 'foo-*', 'repo')
 
 
-def test_list_repository_calls_borg_with_flags():
+def test_list_repository_calls_two_commands():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
-    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
-    rlist_arguments = argparse.Namespace(json=False)
-    global_arguments = flexmock()
-
-    flexmock(module.feature).should_receive('available').and_return(False)
-    flexmock(module).should_receive('make_rlist_command').with_args(
-        repository_path='repo',
-        config={},
-        local_borg_version='1.2.3',
-        rlist_arguments=rlist_arguments,
-        global_arguments=global_arguments,
-        local_path='borg',
-        remote_path=None,
-    ).and_return(('borg', 'rlist', 'repo'))
+    flexmock(module).should_receive('make_rlist_command')
     flexmock(module.environment).should_receive('make_environment')
-    flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'rlist', 'repo'),
-        output_log_level=module.borgmatic.logger.ANSWER,
-        borg_local_path='borg',
-        extra_environment=None,
-    ).once()
+    flexmock(module).should_receive('execute_command_and_capture_output').once()
+    flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags')
+    flexmock(module).should_receive('execute_command').once()
 
     module.list_repository(
         repository_path='repo',
         config={},
         local_borg_version='1.2.3',
-        rlist_arguments=rlist_arguments,
-        global_arguments=global_arguments,
+        rlist_arguments=argparse.Namespace(json=False),
+        global_arguments=flexmock(),
     )
 
 
-def test_list_repository_with_json_returns_borg_output():
+def test_list_repository_with_json_calls_json_command_only():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
-    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
-    rlist_arguments = argparse.Namespace(json=True)
-    global_arguments = flexmock()
-    json_output = flexmock()
-
-    flexmock(module.feature).should_receive('available').and_return(False)
-    flexmock(module).should_receive('make_rlist_command').with_args(
-        repository_path='repo',
-        config={},
-        local_borg_version='1.2.3',
-        rlist_arguments=rlist_arguments,
-        global_arguments=global_arguments,
-        local_path='borg',
-        remote_path=None,
-    ).and_return(('borg', 'rlist', 'repo'))
+    flexmock(module).should_receive('make_rlist_command')
     flexmock(module.environment).should_receive('make_environment')
+    json_output = flexmock()
     flexmock(module).should_receive('execute_command_and_capture_output').and_return(json_output)
+    flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags').never()
+    flexmock(module).should_receive('execute_command').never()
 
     assert (
         module.list_repository(
             repository_path='repo',
             config={},
             local_borg_version='1.2.3',
-            rlist_arguments=rlist_arguments,
-            global_arguments=global_arguments,
+            rlist_arguments=argparse.Namespace(json=True),
+            global_arguments=flexmock(),
         )
         == json_output
     )
